@@ -1,7 +1,7 @@
 // qtractorClip.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -106,12 +106,10 @@ void qtractorClip::clear (void)
 // Clip filename properties accessors.
 void qtractorClip::setFilename ( const QString& sFilename )
 {
-	QDir dir;
-
 	if (m_pTrack && m_pTrack->session())
-		dir.setPath(m_pTrack->session()->sessionDir());
-
-	m_sFilename = QDir::cleanPath(dir.absoluteFilePath(sFilename));
+		m_sFilename = m_pTrack->session()->absoluteFilePath(sFilename);
+	else
+		m_sFilename = QDir::cleanPath(QDir().absoluteFilePath(sFilename));
 }
 
 const QString& qtractorClip::filename (void) const
@@ -119,17 +117,16 @@ const QString& qtractorClip::filename (void) const
 	return m_sFilename;
 }
 
+
 QString qtractorClip::relativeFilename ( qtractorDocument *pDocument ) const
 {
 	if (pDocument && (pDocument->isArchive() || pDocument->isSymLink()))
 		return pDocument->addFile(m_sFilename);
 
-	QDir dir;
-
 	if (m_pTrack && m_pTrack->session())
-		dir.setPath(m_pTrack->session()->sessionDir());
-
-	return dir.relativeFilePath(m_sFilename);
+		return m_pTrack->session()->relativeFilePath(m_sFilename);
+	else
+		return QDir().relativeFilePath(m_sFilename);
 }
 
 
