@@ -1,7 +1,7 @@
 // qtractorClipCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1088,6 +1088,9 @@ qtractorClipToolCommand::~qtractorClipToolCommand (void)
 {
 	qDeleteAll(m_midiEditCommands);
 	m_midiEditCommands.clear();
+
+	qDeleteAll(m_timeScaleNodeCommands);
+	m_timeScaleNodeCommands.clear();
 }
 
 
@@ -1112,6 +1115,14 @@ void qtractorClipToolCommand::addMidiEditCommand (
 }
 
 
+// When additional tempo-map/time-sig nodes are needed.
+void qtractorClipToolCommand::addTimeScaleNodeCommand (
+	qtractorTimeScaleNodeCommand *pTimeScaleNodeCommand )
+{
+	m_timeScaleNodeCommands.append(pTimeScaleNodeCommand);
+}
+
+
 // Composite predicate.
 bool qtractorClipToolCommand::isEmpty (void) const
 {
@@ -1124,6 +1135,8 @@ bool qtractorClipToolCommand::redo (void)
 {
 	++m_iRedoCount;
 
+	executeTimeScaleNodeCommands(true);
+
 	QListIterator<qtractorMidiEditCommand *> iter(m_midiEditCommands);
 	while (iter.hasNext()) {
 		qtractorMidiEditCommand *pMidiEditCommand = iter.next();
@@ -1160,6 +1173,8 @@ bool qtractorClipToolCommand::undo (void)
 		}
 	}
 
+	executeTimeScaleNodeCommands(false);
+
 	return (m_iRedoCount > 0);
 }
 
@@ -1198,6 +1213,31 @@ void qtractorClipToolCommand::swapMidiClipCtx ( qtractorMidiClip *pMidiClip )
 }
 
 
+// Execute tempo-map/time-sig commands.
+void qtractorClipToolCommand::executeTimeScaleNodeCommands ( bool bRedo )
+{
+	int iTimeScaleUpdate = 0;
+	QListIterator<qtractorTimeScaleNodeCommand *> iter(m_timeScaleNodeCommands);
+	if (bRedo)
+		iter.toFront();
+	else
+		iter.toBack();
+	while (bRedo ? iter.hasNext() : iter.hasPrevious()) {
+		qtractorTimeScaleNodeCommand *pTimeScaleNodeCommand
+			= (bRedo ? iter.next() : iter.previous());
+		if (bRedo)
+			pTimeScaleNodeCommand->redo();
+		else
+			pTimeScaleNodeCommand->undo();
+		++iTimeScaleUpdate;
+	}
+
+	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
+	if (pMainForm && iTimeScaleUpdate > 0)
+		pMainForm->updateNotifySlot(qtractorCommand::ClearSelect);
+}
+
+
 //----------------------------------------------------------------------
 // class qtractorClipRecordExCommand - implementation.
 //
