@@ -1,7 +1,7 @@
 // qtractorConnections.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -71,7 +71,7 @@ qtractorConnections::qtractorConnections (
 	// Finally set the default caption and tooltip.
 	const QString& sTitle = tr("Connections");
 	QWidget::setWindowTitle(sTitle);
-	QWidget::setWindowIcon(QIcon(":/images/viewConnections.png"));
+	QWidget::setWindowIcon(QIcon(":/images/qtractorConnections.svg"));
 	QWidget::setToolTip(sTitle);
 
 	// Get previously saved splitter sizes,
