@@ -1,7 +1,7 @@
 // qtractorCurveFile.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -102,8 +102,13 @@ void qtractorCurveFile::load ( QDomElement *pElement )
 						if (eProp.tagName() == "logarithmic")
 							pItem->logarithmic = qtractorDocument::boolFromText(eProp.text());
 						else
-						if (eProp.tagName() == "color")
-							pItem->color.setNamedColor(eProp.text());
+						if (eProp.tagName() == "color") {
+						#if QT_VERSION >= QT_VERSION_CHECK(6, 6, 0)
+							pItem->color = QColor::fromString(eProp.text());
+						#else
+							pItem->color = QColor(eProp.text());
+						#endif
+						}
 					}
 					pItem->subject = nullptr;
 					addItem(pItem);
