@@ -34,6 +34,8 @@
 #include "qtractorDocument.h"
 #include "qtractorCurveFile.h"
 
+#include "qtractorFileList.h"
+
 #include <QDomDocument>
 #include <QFileInfo>
 
@@ -728,7 +730,11 @@ void qtractorBus::saveCurveFile ( qtractorDocument *pDocument,
 		return;
 
 	const QString sBaseName(sBusName + "_curve");
-	pCurveFile->setFilename(pSession->createFilePath(sBaseName, "mid", true));
+	const bool bTemporary = pDocument->isTemporary();
+	const QString& sFilename
+		= pSession->createFilePath(sBaseName, "mid", !bTemporary);
+	pSession->files()->addFileItem(qtractorFileList::Midi, sFilename, bTemporary);
+	pCurveFile->setFilename(sFilename);
 
 	pCurveFile->save(pDocument, pElement, pSession->timeScale());
 }
