@@ -1,7 +1,7 @@
 // qtractorFileListView.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -27,7 +27,6 @@
 
 #include "qtractorOptions.h"
 #include "qtractorSession.h"
-#include "qtractorClip.h"
 
 #include <QDomDocument>
 
@@ -39,7 +38,6 @@
 #include <QToolTip>
 #include <QTimer>
 #include <QUrl>
-#include <QDir>
 
 #include <QMouseEvent>
 #include <QDragLeaveEvent>
@@ -390,7 +388,7 @@ qtractorFileListItem *qtractorFileListView::addFileItem (
 		pFileItem = createFileItem(sPath);
 		if (pFileItem) {
 			// Add to file/path registry...
-			pSession->files()->addFileItem(m_iFileType, pFileItem);
+			pSession->files()->addFileItem(m_iFileType, pFileItem->path());
 			// Insert the new file item in place...
 			if (pParentItem) {
 				if (pParentItem->type() == GroupItem) {
@@ -447,6 +445,31 @@ qtractorFileGroupItem *qtractorFileListView::addGroupItem (
 }
 
 
+// Remove an existing group item, by name (should be unique).
+void qtractorFileListView::removeGroupItem ( const QString& sName )
+{
+	qtractorFileGroupItem *pGroupItem = findGroupItem(sName);
+	if (pGroupItem) {
+		delete pGroupItem;
+	//	emit contentsChanged();
+	}
+}
+
+
+// Remove an existing file item, by path (should be unique).
+void qtractorFileListView::removeFileItem ( const QString& sPath )
+{
+	qtractorFileListItem *pFileItem = findFileItem(sPath);
+	if (pFileItem) {
+		qtractorSession *pSession = qtractorSession::getInstance();
+		if (pSession)
+			pSession->files()->removeFileItem(m_iFileType, pFileItem->path());
+		delete pFileItem;
+	//	emit contentsChanged();
+	}
+}
+
+
 // Current group item accessor...
 qtractorFileGroupItem *qtractorFileListView::currentGroupItem (void) const
 {
@@ -673,7 +696,7 @@ void qtractorFileListView::removeItem (void)
 				qtractorFileListItem *pFileItem
 					= static_cast<qtractorFileListItem *> (pItem);
 				if (pFileItem)
-					pSession->files()->removeFileItem(m_iFileType, pFileItem);
+					pSession->files()->removeFileItem(m_iFileType, pFileItem->path());
 			}
 			// Scrap view item...
 			delete pItem;
@@ -701,7 +724,7 @@ void qtractorFileListView::removeItem (void)
 					qtractorFileListItem *pFileItem
 						= static_cast<qtractorFileListItem *> (pItem);
 					if (pFileItem)
-						pSession->files()->removeFileItem(m_iFileType, pFileItem);
+						pSession->files()->removeFileItem(m_iFileType, pFileItem->path());
 				}
 			}
 			// Scrap view item...
@@ -1399,9 +1422,6 @@ bool qtractorFileListView::loadListElement (
 	if (pSession == nullptr)
 		return false;
 
-	// Make it all relative to session directory...
-	const QDir dir(pSession->sessionDir());
-
 	// Load children...
 	for (QDomNode nChild = pElement->firstChild();
 			!nChild.isNull(); nChild = nChild.nextSibling()) {
@@ -1425,7 +1445,7 @@ bool qtractorFileListView::loadListElement (
 		else
 		if (eChild.tagName() == "file") {
 			qtractorFileListItem *pFileItem = createFileItem(
-				QDir::cleanPath(dir.absoluteFilePath(eChild.text())));
+				pSession->absoluteFilePath(eChild.text()));
 			if (pFileItem) {
 				pFileItem->setText(0, eChild.attribute("name"));
 				if (pParentItem)
@@ -1433,7 +1453,7 @@ bool qtractorFileListView::loadListElement (
 				else
 					QTreeWidget::addTopLevelItem(pFileItem);
 				if (pSession)
-					pSession->files()->addFileItem(m_iFileType, pFileItem);
+					pSession->files()->addFileItem(m_iFileType, pFileItem->path());
 			}
 		}
 	}
@@ -1486,12 +1506,10 @@ bool qtractorFileListView::saveListElement (
 			&& (pFileListItem->clipRefCount() > 0
 			|| !pFileListItem->isAutoRemove())) {
 			// Make it all relative to archive or session directory...
-			if (pDocument->isArchive() || pDocument->isSymLink()) {
+			if (pDocument->isArchive() || pDocument->isSymLink())
 				sPath = pDocument->addFile(sPath);
-			} else {
-				const QDir dir(pSession->sessionDir());
-				sPath = dir.relativeFilePath(sPath);
-			}
+			else
+				sPath = pSession->relativeFilePath(sPath);
 			// Save file item if valid...
 			QDomElement eFile = pDocument->document()->createElement("file");
 			eFile.setAttribute("name", pFileItem->text(0));
