@@ -24,6 +24,8 @@
 #include "qtractorMidiClip.h"
 #include "qtractorMidiEngine.h"
 
+#include "qtractorTimeScaleCommand.h"
+
 #include "qtractorSession.h"
 
 
@@ -52,6 +54,10 @@ qtractorMidiEditCommand::~qtractorMidiEditCommand (void)
 
 	qDeleteAll(m_items);
 	m_items.clear();
+
+	qDeleteAll(m_timeScaleNodeCommands);
+	m_timeScaleNodeCommands.clear();
+
 }
 
 
@@ -127,6 +133,9 @@ bool qtractorMidiEditCommand::execute ( bool bRedo )
 	if (pSeq == nullptr)
 		return false;
 
+	// Execute all additional commands....
+	executeTimeScaleNodeCommands(bRedo);
+
 	// Dropped enqueued events...
 	qtractorSession *pSession = nullptr;
 	qtractorTrack *pTrack = m_pMidiClip->track();
@@ -436,6 +445,38 @@ bool qtractorMidiEditCommand::adjust (void)
 }
 
 
+// Add a time-scale command to the execution list...
+void qtractorMidiEditCommand::addTimeScaleNodeCommand (
+	qtractorTimeScaleNodeCommand *pTimeScaleNodeCommand )
+{
+	m_timeScaleNodeCommands.append(pTimeScaleNodeCommand);
+}
+
+
+// Execute tempo-map/time-sig commands.
+void qtractorMidiEditCommand::executeTimeScaleNodeCommands ( bool bRedo )
+{
+	int iTimeScaleUpdate = 0;
+	QListIterator<qtractorTimeScaleNodeCommand *> iter(m_timeScaleNodeCommands);
+	if (bRedo)
+		iter.toFront();
+	else
+		iter.toBack();
+	while (bRedo ? iter.hasNext() : iter.hasPrevious()) {
+		qtractorTimeScaleNodeCommand *pTimeScaleNodeCommand
+			= (bRedo ? iter.next() : iter.previous());
+		if (bRedo)
+			pTimeScaleNodeCommand->redo();
+		else
+			pTimeScaleNodeCommand->undo();
+		++iTimeScaleUpdate;
+	}
+
+	if (m_pMidiClip && iTimeScaleUpdate > 0)
+		m_pMidiClip->updateEditorTimeScale();
+}
+
+
 // Virtual command methods.
 bool qtractorMidiEditCommand::redo (void)
 {
