@@ -1,7 +1,7 @@
 // qtractorMidiEditTime.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -92,6 +92,9 @@ protected:
 	void showToolTip(unsigned long iFrame) const;
 	void showToolTip(const QRect& rect) const;
 
+	// Edit-head/tail positioning...
+	void selectEdit(unsigned long iFrame);
+
 protected slots:
 
 	// To have timeline in h-sync with main track view.
