@@ -27,6 +27,8 @@
 
 #include "qtractorMidiEditCommand.h"
 
+#include "qtractorTimeScaleCommand.h"
+
 #include "qtractorOptions.h"
 #include "qtractorSession.h"
 
@@ -163,26 +165,36 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 		// Fill-up snap-per-beat items...
 		const QIcon snapIcon(":/images/itemBeat.png");
 		const QSize snapIconSize(8, 16);
-		const QStringList& snapItems = qtractorTimeScale::snapItems(1);
+		const QStringList& snapItems = qtractorTimeScale::snapItems();
 		QStringListIterator snapIter(snapItems);
 		m_ui.QuantizeTimeComboBox->clear();
 		m_ui.QuantizeTimeComboBox->setIconSize(snapIconSize);
 	//	snapIter.toFront();
+		snapIter.next();
 		while (snapIter.hasNext())
 			m_ui.QuantizeTimeComboBox->addItem(snapIcon, snapIter.next());
 	//	m_ui.QuantizeTimeComboBox->insertItems(0, snapItems);
 		m_ui.QuantizeDurationComboBox->clear();
 		m_ui.QuantizeDurationComboBox->setIconSize(snapIconSize);
 		snapIter.toFront();
+		snapIter.next();
 		while (snapIter.hasNext())
 			m_ui.QuantizeDurationComboBox->addItem(snapIcon, snapIter.next());
 	//	m_ui.QuantizeDurationComboBox->insertItems(0, snapItems);
 		m_ui.QuantizeSwingComboBox->clear();
 		m_ui.QuantizeSwingComboBox->setIconSize(snapIconSize);
 		snapIter.toFront();
+		snapIter.next();
 		while (snapIter.hasNext())
 			m_ui.QuantizeSwingComboBox->addItem(snapIcon, snapIter.next());
 	//	m_ui.QuantizeSwingComboBox->insertItems(0, snapItems);
+		m_ui.ResizeLegatoLengthComboBox->clear();
+		m_ui.ResizeLegatoLengthComboBox->setIconSize(snapIconSize);
+		snapIter.toFront();
+		snapIter.next();
+		while (snapIter.hasNext())
+			m_ui.ResizeLegatoLengthComboBox->addItem(snapIcon, snapIter.next());
+	//	m_ui.ResizeLegatoQuantizeComboBox->insertItems(0, snapItems);
 		// Default quantization value...
 		unsigned short iSnapPerBeat = m_pTimeScale->snapPerBeat();
 		if (iSnapPerBeat > 0)
@@ -192,6 +204,32 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 		m_ui.QuantizeDurationComboBox->setCurrentIndex(iSnapIndex);
 		m_ui.QuantizeSwingComboBox->setCurrentIndex(0);
 		m_ui.QuantizeSwingTypeComboBox->setCurrentIndex(0);
+		m_ui.ResizeLegatoLengthComboBox->setCurrentIndex(iSnapIndex);
+		// Initial tempo-ramp range...
+		if (pSession->editHead() < pSession->editTail()) {
+			qtractorTimeScale::Cursor cursor(m_pTimeScale);
+			qtractorTimeScale::Node *pNode = cursor.seekFrame(pSession->editHead());
+			const float T1 = pNode->tempo;
+			const unsigned short iBeatsPerBar1
+				= pNode->beatsPerBar;
+			const unsigned short iBeatDivisor1
+				= pNode->beatDivisor;
+			qtractorTimeScale::Node *pPrev = pNode->prev();
+			const float T0 = pPrev ? pPrev->tempo : T1;
+			const unsigned short iBeatsPerBar0
+				= pPrev ? pPrev->beatsPerBar : iBeatsPerBar1;
+			const unsigned short iBeatDivisor0
+				= pPrev ? pPrev->beatDivisor : iBeatDivisor1;
+			m_ui.TemporampFromSpinBox->setTempo(T0);
+			m_ui.TemporampFromSpinBox->setBeatsPerBar(iBeatsPerBar0);
+			m_ui.TemporampFromSpinBox->setBeatDivisor(iBeatDivisor0);
+			m_ui.TemporampToSpinBox->setTempo(T1);
+			m_ui.TemporampToSpinBox->setBeatsPerBar(iBeatsPerBar1);
+			m_ui.TemporampToSpinBox->setBeatDivisor(iBeatDivisor1);
+		} else {
+			m_ui.Timeshift->setEnabled(false);
+			m_ui.Temporamp->setEnabled(false);
+		}
 	}
 
 	// Scale-quantize stuff...
@@ -212,8 +250,6 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 	timeshiftSpinBoxChanged(m_ui.TimeshiftSpinBox->value());
 	refreshPresets();
 
-	// Draw timeshift curve always.
-
 	// Try to restore old window positioning.
 	// adjustSize();
 
@@ -352,10 +388,9 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 	QObject::connect(m_ui.ResizeDurationSpinBox,
 		SIGNAL(valueChanged(unsigned long)),
 		SLOT(changed()));
-	QObject::connect(m_ui.ResizeFormatComboBox,
+	QObject::connect(m_ui.ResizeDurationFormatComboBox,
 		SIGNAL(activated(int)),
 		SLOT(formatChanged(int)));
-
 	QObject::connect(m_ui.ResizeValueCheckBox,
 		SIGNAL(toggled(bool)),
 		SLOT(changed()));
@@ -368,6 +403,18 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 	QObject::connect(m_ui.ResizeValue2SpinBox,
 		SIGNAL(valueChanged(int)),
 		SLOT(changed()));
+	QObject::connect(m_ui.ResizeLegatoCheckBox,
+		SIGNAL(toggled(bool)),
+		SLOT(changed()));
+	QObject::connect(m_ui.ResizeLegatoTypeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(changed()));
+	QObject::connect(m_ui.ResizeLegatoLengthComboBox,
+		SIGNAL(activated(int)),
+		SLOT(changed()));
+	QObject::connect(m_ui.ResizeLegatoModeComboBox,
+		SIGNAL(activated(int)),
+		SLOT(changed()));
 
 	QObject::connect(m_ui.RescaleCheckBox,
 		SIGNAL(toggled(bool)),
@@ -390,6 +437,9 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 	QObject::connect(m_ui.RescaleValueSpinBox,
 		SIGNAL(valueChanged(double)),
 		SLOT(changed()));
+	QObject::connect(m_ui.RescaleInvertCheckBox,
+		 SIGNAL(toggled(bool)),
+		 SLOT(changed()));
 
 	QObject::connect(m_ui.TimeshiftCheckBox,
 		SIGNAL(toggled(bool)),
@@ -404,6 +454,19 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 		SIGNAL(toggled(bool)),
 		SLOT(changed()));
 
+	QObject::connect(m_ui.TemporampCheckBox,
+		SIGNAL(toggled(bool)),
+		SLOT(stabilizeForm()));
+	QObject::connect(m_ui.TemporampFromSpinBox,
+		SIGNAL(valueChanged(const QString&)),
+		SLOT(changed()));
+	QObject::connect(m_ui.TemporampToSpinBox,
+		SIGNAL(valueChanged(const QString&)),
+		SLOT(changed()));
+	QObject::connect(m_ui.TemporampDurationCheckBox,
+		SIGNAL(toggled(bool)),
+		SLOT(changed()));
+
 	QObject::connect(m_ui.DialogButtonBox,
 		SIGNAL(accepted()),
 		SLOT(accept()));
@@ -416,6 +479,9 @@ qtractorMidiToolsForm::qtractorMidiToolsForm ( QWidget *pParent )
 // Destructor.
 qtractorMidiToolsForm::~qtractorMidiToolsForm (void)
 {
+	qDeleteAll(m_timeScaleNodeCommands);
+	m_timeScaleNodeCommands.clear();
+
 	// Don't forget to get rid of local time-scale instance...
 	if (m_pTimeScale)
 		delete m_pTimeScale;
@@ -449,6 +515,9 @@ void qtractorMidiToolsForm::setToolIndex ( int iToolIndex )
 	case qtractorMidiEditor::Timeshift:
 		m_ui.TimeshiftCheckBox->setChecked(true);
 		break;
+	case qtractorMidiEditor::Temporamp:
+		m_ui.TemporampCheckBox->setChecked(true);
+		break;
 	default:
 		break;
 	}
@@ -552,6 +621,13 @@ void qtractorMidiToolsForm::loadPreset ( const QString& sPreset )
 			m_ui.ResizeValue2ComboBox->setCurrentIndex(vlist[5].toInt());
 			m_ui.ResizeValue2SpinBox->setValue(vlist[6].toInt());
 		}
+		// Resize legato mode tool...
+		if (vlist.count() > 10) {
+			m_ui.ResizeLegatoCheckBox->setChecked(vlist[7].toBool());
+			m_ui.ResizeLegatoTypeComboBox->setCurrentIndex(vlist[8].toInt());
+			m_ui.ResizeLegatoLengthComboBox->setCurrentIndex(vlist[9].toInt());
+			m_ui.ResizeLegatoModeComboBox->setCurrentIndex(vlist[10].toInt());
+		}
 		// Rescale tool...
 		vlist = settings.value("/Rescale").toList();
 		if (vlist.count() > 6) {
@@ -563,6 +639,9 @@ void qtractorMidiToolsForm::loadPreset ( const QString& sPreset )
 			m_ui.RescaleValueCheckBox->setChecked(vlist[5].toBool());
 			m_ui.RescaleValueSpinBox->setValue(vlist[6].toDouble());
 		}
+		// Rescale/invert tool...
+		if (vlist.count() > 7)
+			m_ui.RescaleInvertCheckBox->setChecked(vlist[7].toBool());
 		// Timeshift tool...
 		vlist = settings.value("/Timeshift").toList();
 		if (vlist.count() > 2) {
@@ -570,6 +649,14 @@ void qtractorMidiToolsForm::loadPreset ( const QString& sPreset )
 			m_ui.TimeshiftSpinBox->setValue(vlist[1].toDouble());
 			m_ui.TimeshiftDurationCheckBox->setChecked(vlist[2].toBool());
 		}
+		// Temporamp tool...
+		vlist = settings.value("/Temporamp").toList();
+		if (vlist.count() > 3) {
+		//	m_ui.TemporampCheckBox->setChecked(vlist[0].toBool());
+		//	m_ui.TemporampFromSpinBox->setTempo(vlist[1].toDouble());
+			m_ui.TemporampToSpinBox->setTempo(float(vlist[2].toDouble()));
+			m_ui.TemporampDurationCheckBox->setChecked(float(vlist[3].toBool()));
+		}
 		// All loaded.
 		if (!sPreset.isEmpty() && sPreset != g_sDefPreset)
 			settings.endGroup();
@@ -644,6 +731,10 @@ void qtractorMidiToolsForm::savePreset ( const QString& sPreset )
 		vlist.append((unsigned int) m_ui.ResizeDurationSpinBox->value());
 		vlist.append(m_ui.ResizeValue2ComboBox->currentIndex());
 		vlist.append(m_ui.ResizeValue2SpinBox->value());
+		vlist.append(m_ui.ResizeLegatoCheckBox->isChecked());
+		vlist.append(m_ui.ResizeLegatoTypeComboBox->currentIndex());
+		vlist.append(m_ui.ResizeLegatoLengthComboBox->currentIndex());
+		vlist.append(m_ui.ResizeLegatoModeComboBox->currentIndex());
 		settings.setValue("/Resize", vlist);
 		// Rescale tool...
 		vlist.clear();
@@ -654,6 +745,7 @@ void qtractorMidiToolsForm::savePreset ( const QString& sPreset )
 		vlist.append(m_ui.RescaleDurationSpinBox->value());
 		vlist.append(m_ui.RescaleValueCheckBox->isChecked());
 		vlist.append(m_ui.RescaleValueSpinBox->value());
+		vlist.append(m_ui.RescaleInvertCheckBox->isChecked());
 		settings.setValue("/Rescale", vlist);
 		// Timeshift tool...
 		vlist.clear();
@@ -661,6 +753,13 @@ void qtractorMidiToolsForm::savePreset ( const QString& sPreset )
 		vlist.append(m_ui.TimeshiftSpinBox->value());
 		vlist.append(m_ui.TimeshiftDurationCheckBox->isChecked());
 		settings.setValue("/Timeshift", vlist);
+		// Temporamp tool...
+		vlist.clear();
+		vlist.append(m_ui.TemporampCheckBox->isChecked());
+		vlist.append(m_ui.TemporampFromSpinBox->tempo());
+		vlist.append(m_ui.TemporampToSpinBox->tempo());
+		vlist.append(m_ui.TemporampDurationCheckBox->isChecked());
+		settings.setValue("/Temporamp", vlist);
 		// All saved.
 		if (!sPreset.isEmpty() && sPreset != g_sDefPreset)
 			settings.endGroup();
@@ -765,12 +864,16 @@ void qtractorMidiToolsForm::presetDelete (void)
 
 
 // Create edit command based on given selection.
-qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
+qtractorMidiEditCommand *qtractorMidiToolsForm::midiEditCommand (
 	qtractorMidiClip *pMidiClip, qtractorMidiEditSelect *pSelect,
 	unsigned long iTimeOffset, unsigned long iTimeStart, unsigned long iTimeEnd )
 {
+	qtractorSession *pSession = qtractorSession::getInstance();
+	if (pSession == nullptr)
+		return nullptr;
+
 	// Create command, it will be handed over...
-	qtractorMidiEditCommand *pEditCommand
+	qtractorMidiEditCommand *pMidiEditCommand
 		= new qtractorMidiEditCommand(pMidiClip, tr("none"));
 
 	// Set composite command title.
@@ -789,11 +892,24 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 		tools.append(tr("rescale"));
 	if (m_ui.TimeshiftCheckBox->isChecked())
 		tools.append(tr("timeshift"));
-	pEditCommand->setName(tools.join(", "));
+	if (m_ui.TemporampCheckBox->isChecked())
+		tools.append(tr("temporamp"));
+	pMidiEditCommand->setName(tools.join(", "));
 
-	const qtractorMidiEditSelect::ItemList& items = pSelect->items();
-	qtractorMidiEditSelect::ItemList::ConstIterator iter = items.constBegin();
-	const qtractorMidiEditSelect::ItemList::ConstIterator& iter_end = items.constEnd();
+	QList<qtractorMidiEvent *> items = pSelect->items().keys();
+
+	if (m_ui.ResizeCheckBox->isChecked()
+		&& m_ui.ResizeLegatoCheckBox->isChecked()) {
+		// Sort events in reverse event time...
+		struct ReverseEventTime {
+			bool operator() (qtractorMidiEvent *ev1, qtractorMidiEvent *ev2) const
+				{ return (ev1->time() > ev2->time()); }
+		};
+		std::sort(items.begin(), items.end(), ReverseEventTime());
+	}
+
+	QList<qtractorMidiEvent *>::ConstIterator iter = items.constBegin();
+	const QList<qtractorMidiEvent *>::ConstIterator& iter_end = items.constEnd();
 
 	// Seed time range with a value from the list of selected events.
 	long iMinTime = iTimeOffset;
@@ -822,7 +938,7 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 			m_ui.ResizeValue2ComboBox->currentIndex() > 0)) {
 		// Make it through one time...
 		for (int i = 0 ; iter != iter_end; ++i, ++iter) {
-			qtractorMidiEvent *pEvent = iter.key();
+			qtractorMidiEvent *pEvent = *iter;
 			const long iTime = pEvent->time() + iTimeOffset;
 			const long iTime2 = iTime + pEvent->duration();
 			if (iMinTime  > iTime)
@@ -833,8 +949,10 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 				iMinTime2 = iTime;
 			if (iMaxTime2 < iTime2)
 				iMaxTime2 = iTime2;
-			const bool bPitchBend = (pEvent->type() == qtractorMidiEvent::PITCHBEND);
-			const int iValue = (bPitchBend ? pEvent->pitchBend() : pEvent->value());
+			const bool bPitchBend
+				= (pEvent->type() == qtractorMidiEvent::PITCHBEND);
+			const int iValue
+				= (bPitchBend ? pEvent->pitchBend() : pEvent->value());
 			if (iMinValue > iValue || i == 0)
 				iMinValue = iValue;
 			if (iMaxValue < iValue)
@@ -847,12 +965,20 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 	// Go for the main pass...
 	qtractorTimeScale::Cursor cursor(m_pTimeScale);
 
+	// Resize/Legato: to track last event...
+	qtractorMidiEvent *pLastEvent = nullptr;
+
 	for ( ; iter != iter_end; ++iter) {
-		qtractorMidiEvent *pEvent = iter.key();
+		qtractorMidiEvent *pEvent = *iter;
 		int iNote = int(pEvent->note());
 		long iTime = pEvent->time() + iTimeOffset;
 		long iDuration = long(pEvent->duration());
-		const bool bPitchBend = (pEvent->type() == qtractorMidiEvent::PITCHBEND);
+		const bool bPitchBend = (
+			pEvent->type() == qtractorMidiEvent::PITCHBEND);
+		const bool b14bit = (
+			pEvent->type() == qtractorMidiEvent::CONTROL14 ||
+			pEvent->type() == qtractorMidiEvent::REGPARAM  ||
+			pEvent->type() == qtractorMidiEvent::NONREGPARAM);
 		int iValue = (bPitchBend ? pEvent->pitchBend() : pEvent->value());
 		qtractorTimeScale::Node *pNode = cursor.seekTick(iTime);
 		// Quantize tool...
@@ -944,7 +1070,13 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 			if (m_ui.NormalizeValueCheckBox->isChecked())
 				p = float(m_ui.NormalizeValueSpinBox->value());
 			else
-				p = (bPitchBend ? 8192.0f : 128.0f);
+			if (b14bit)
+				p = 16384.0f;
+			else
+			if (bPitchBend)
+				p = 8192.0f;
+			else
+				p = 128.0f;
 			if (m_ui.NormalizePercentCheckBox->isChecked()) {
 				p *= float(m_ui.NormalizePercentSpinBox->value());
 				q *= 100.0f;
@@ -958,6 +1090,9 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 					if (iValue < -8191)
 						iValue = -8191;
 				} else {
+					if (iValue > 16383 && b14bit)
+						iValue = 16383;
+					else
 					if (iValue > 127)
 						iValue = 127;
 					else
@@ -1012,7 +1147,10 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 						if (iValue < -8191)
 							iValue = -8191;
 					} else {
-						if (iValue > 127)
+						if (iValue > 16383 && b14bit)
+							iValue = 16383;
+						else
+						if (iValue > 127 && !b14bit)
 							iValue = 127;
 						else
 						if (iValue < 0)
@@ -1023,9 +1161,17 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 		}
 		// Resize tool...
 		if (m_ui.ResizeCheckBox->isChecked()) {
-			if (m_ui.ResizeDurationCheckBox->isChecked()) {
-				iDuration = pNode->tickFromFrame(pNode->frameFromTick(iTime)
-					+ m_ui.ResizeDurationSpinBox->value()) - iTime;
+			if (m_ui.ResizeDurationCheckBox->isChecked()
+				&& pEvent->type() == qtractorMidiEvent::NOTEON) {
+				const float T0 // @ iFrame == 0
+					= m_pTimeScale->nodes().first()->tempo;
+				const float T1
+					= pNode->tempo;
+				const unsigned long iFrames
+					= qtractorTimeScale::uroundf(
+						T0 * float(m_ui.ResizeDurationSpinBox->value()) / T1);
+				iDuration = pNode->tickFromFrame(
+					pNode->frameFromTick(iTime) + iFrames) - iTime;
 			}
 			if (m_ui.ResizeValueCheckBox->isChecked()) {
 				const int p = (bPitchBend && iValue < 0 ? -1 : 1); // sign
@@ -1040,6 +1186,26 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 						iValue += iDeltaValue * (iTime - iMinTime) / iDeltaTime;
 				}
 			}
+			if (m_ui.ResizeLegatoCheckBox->isChecked()
+				&& pEvent->type() == qtractorMidiEvent::NOTEON) {
+				if (pLastEvent) {
+					long d2 = long(float(pLastEvent->time() - pEvent->time()));
+					const int i	= m_ui.ResizeLegatoTypeComboBox->currentIndex();
+					if (i > 0) {
+						const unsigned short p = qtractorTimeScale::snapFromIndex(
+							m_ui.ResizeLegatoLengthComboBox->currentIndex());
+						const unsigned long q = pNode->ticksPerBeat / p;
+						d2 += (i == 1 ? -long(q) : +long(q));
+					}
+					if (m_ui.ResizeLegatoModeComboBox->currentIndex() > 0) {
+						if (iDuration < d2 && d2 > 0)
+							iDuration = d2;
+					}
+					else if (d2 > 0)
+						iDuration = d2;
+				}
+				pLastEvent = pEvent;
+			}
 		}
 		// Rescale tool...
 		if (m_ui.RescaleCheckBox->isChecked()) {
@@ -1058,6 +1224,15 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 			}
 			if (m_ui.RescaleValueCheckBox->isChecked()) {
 				p = 0.01f * float(m_ui.RescaleValueSpinBox->value());
+				if (m_ui.RescaleInvertCheckBox->isChecked()) {
+					if (bPitchBend)
+						iValue = -iValue;
+					else
+					if (b14bit)
+						iValue = 16384 - iValue;
+					else
+						iValue = (b14bit ? 16384 : 128) - iValue;
+				}
 				iValue = int(p * float(iValue));
 				if (bPitchBend) {
 					if (iValue > +8191)
@@ -1066,7 +1241,10 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 					if (iValue < -8191)
 						iValue = -8191;
 				} else {
-					if (iValue > 127)
+					if (iValue > 16383 && b14bit)
+						iValue = 16383;
+					else
+					if (iValue > 127 && !b14bit)
 						iValue = 127;
 					else
 					if (iValue < 0)
@@ -1076,7 +1254,6 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 		}
 		// Timeshift tool...
 		if (m_ui.TimeshiftCheckBox->isChecked()) {
-			qtractorSession *pSession = qtractorSession::getInstance();
 			const unsigned long iEditHeadTime
 				= pSession->tickFromFrame(pSession->editHead());
 			const unsigned long iEditTailTime
@@ -1097,13 +1274,54 @@ qtractorMidiEditCommand *qtractorMidiToolsForm::editCommand (
 				}
 			}
 		}
+		// Temporamp tool...
+		if (m_ui.TemporampCheckBox->isChecked()) {
+			const unsigned long iEditHeadTime
+				= pSession->tickFromFrame(pSession->editHead());
+			const unsigned long iEditTailTime
+				= pSession->tickFromFrame(pSession->editTail());
+			const float d = float(iEditTailTime - iEditHeadTime);
+			const float T0 = m_ui.TemporampFromSpinBox->tempo();
+			const float T1 = m_ui.TemporampToSpinBox->tempo();
+			float t2 = float(iTime - iEditHeadTime) / d;
+			const float s2
+				= (T1 - T0) / (T0 > T1 ? T0 : T1)
+				* (1.0f - t2 * t2);
+			if (m_ui.TemporampDurationCheckBox->isChecked()) {
+				const float d2 = s2 * float(iDuration) / d;
+				iDuration += qtractorTimeScale::uroundf(d2 * d);
+			}
+			t2 += s2 * t2 * ::expf(- t2 * M_PI);
+			iTime = iEditHeadTime + qtractorTimeScale::uroundf(t2 * d);
+		}
 		// Make it to the event...
-		pEditCommand->updateEvent(pEvent,
+		pMidiEditCommand->updateEvent(pEvent,
 			iNote, iTime - iTimeOffset, iDuration, iValue);
 	}
 
+	// HACK: Add time-scale node for tempo ramp target,
+	// iif not the same to current edit-head's tempo.
+	// FIXME: conditional check-box at the UI level?
+	if (m_ui.TemporampCheckBox->isChecked()) {
+		qtractorTimeScale *pTimeScale = pSession->timeScale();
+		qtractorTimeScale::Cursor cursor(pTimeScale);
+		const unsigned long iEditHead = pSession->editHead();
+		qtractorTimeScale::Node *pNode = cursor.seekFrame(iEditHead);
+		const float T1 = m_ui.TemporampToSpinBox->tempo();
+		if (qAbs(T1 - pNode->tempo) > 0.05f) {
+			const unsigned short iBeatsPerBar1
+				= m_ui.TemporampToSpinBox->beatsPerBar();
+			const unsigned short iBeatDivisor1
+				= m_ui.TemporampToSpinBox->beatDivisor();
+			m_timeScaleNodeCommands.append(
+				new qtractorTimeScaleAddNodeCommand(
+					pTimeScale, iEditHead, T1, pNode->beatType,
+					iBeatsPerBar1, iBeatDivisor1));
+		}
+	}
+
 	// Done.
-	return pEditCommand;
+	return pMidiEditCommand;
 }
 
 
@@ -1144,7 +1362,7 @@ void qtractorMidiToolsForm::formatChanged ( int iDisplayFormat )
 		= qtractorTimeScale::DisplayFormat(iDisplayFormat);
 
 	m_ui.TransposeFormatComboBox->setCurrentIndex(iDisplayFormat);
-	m_ui.ResizeFormatComboBox->setCurrentIndex(iDisplayFormat);
+	m_ui.ResizeDurationFormatComboBox->setCurrentIndex(iDisplayFormat);
 
 	if (m_pTimeScale) {
 		// Set from local time-scale instance...
@@ -1223,7 +1441,9 @@ void qtractorMidiToolsForm::stabilizeForm (void)
 		++iEnabled;
 	m_ui.TransposeTimeSpinBox->setEnabled(bEnabled2);
 	m_ui.TransposeFormatComboBox->setEnabled(bEnabled2);
-	bEnabled2 = bEnabled && m_ui.TransposeReverseCheckBox->isChecked();
+
+	m_ui.TransposeReverseCheckBox->setEnabled(bEnabled2);
+	bEnabled2 = bEnabled2 && m_ui.TransposeReverseCheckBox->isChecked();
 	if (bEnabled2)
 		++iEnabled;
 
@@ -1280,7 +1500,7 @@ void qtractorMidiToolsForm::stabilizeForm (void)
 	if (bEnabled2)
 		++iEnabled;
 	m_ui.ResizeDurationSpinBox->setEnabled(bEnabled2);
-	m_ui.ResizeFormatComboBox->setEnabled(bEnabled2);
+	m_ui.ResizeDurationFormatComboBox->setEnabled(bEnabled2);
 
 	m_ui.ResizeValueCheckBox->setEnabled(bEnabled);
 	bEnabled2 = bEnabled && m_ui.ResizeValueCheckBox->isChecked();
@@ -1292,6 +1512,15 @@ void qtractorMidiToolsForm::stabilizeForm (void)
 		bEnabled2 = (m_ui.ResizeValue2ComboBox->currentIndex() > 0);
 	m_ui.ResizeValue2SpinBox->setEnabled(bEnabled2);
 
+	m_ui.ResizeLegatoCheckBox->setEnabled(bEnabled);
+	bEnabled2 = bEnabled && m_ui.ResizeLegatoCheckBox->isChecked();
+	if (bEnabled2)
+		++iEnabled;
+	m_ui.ResizeLegatoTypeComboBox->setEnabled(bEnabled2);
+	m_ui.ResizeLegatoLengthComboBox->setEnabled(bEnabled2
+		&& m_ui.ResizeLegatoTypeComboBox->currentIndex() > 0);
+	m_ui.ResizeLegatoModeComboBox->setEnabled(bEnabled2);
+
 	// Rescale tool...
 
 	bEnabled = m_ui.RescaleCheckBox->isChecked();
@@ -1314,6 +1543,11 @@ void qtractorMidiToolsForm::stabilizeForm (void)
 		++iEnabled;
 	m_ui.RescaleValueSpinBox->setEnabled(bEnabled2);
 
+	m_ui.RescaleInvertCheckBox->setEnabled(bEnabled2);
+	bEnabled2 = bEnabled2 && m_ui.RescaleInvertCheckBox->isChecked();
+	if (bEnabled2)
+		++iEnabled;
+
 	// Timeshift tool...
 
 	bEnabled = m_ui.TimeshiftCheckBox->isChecked();
@@ -1326,6 +1560,23 @@ void qtractorMidiToolsForm::stabilizeForm (void)
 	m_ui.TimeshiftDurationCheckBox->setEnabled(bEnabled);
 	m_pTimeshiftCurve->setVisible(bEnabled);
 
+	// Temporamp tool...
+
+	bEnabled = m_ui.TemporampCheckBox->isChecked();
+	if (bEnabled)
+		++iEnabled;
+	m_ui.TemporampFromLabel->setEnabled(bEnabled);
+	m_ui.TemporampFromSpinBox->setEnabled(false);
+	m_ui.TemporampToLabel->setEnabled(bEnabled);
+	m_ui.TemporampToSpinBox->setEnabled(bEnabled);
+	m_ui.TemporampText->setEnabled(bEnabled);
+	m_ui.TemporampDurationCheckBox->setEnabled(bEnabled);
+	if (bEnabled
+		&& qAbs(
+			m_ui.TemporampFromSpinBox->tempo() -
+			m_ui.TemporampToSpinBox->tempo()) < 0.01f)
+		iEnabled = 0;
+
 	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(iEnabled > 0);
 }
 
@@ -1384,4 +1635,18 @@ void qtractorMidiToolsForm::timeshiftSliderChanged ( int i )
 }
 
 
+// Special tempo ramp tool helper...
+qtractorTimeScaleNodeCommand *qtractorMidiToolsForm::timeScaleNodeCommand (void)
+{
+	if (m_timeScaleNodeCommands.isEmpty())
+		return nullptr;
+
+	qtractorTimeScaleNodeCommand *pTimeScaleNodeCommand
+		= m_timeScaleNodeCommands.at(0);
+	m_timeScaleNodeCommands.removeAt(0);
+
+	return pTimeScaleNodeCommand;
+}
+
+
 // end of qtractorMidiToolsForm.cpp
