@@ -1,7 +1,7 @@
 // qtractorOptions.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -394,6 +394,7 @@ void qtractorOptions::loadOptions (void)
 	m_settings.beginGroup("/Custom");
 	sCustomColorTheme = m_settings.value("/ColorTheme").toString();
 	sCustomStyleTheme = m_settings.value("/StyleTheme").toString();
+	sCustomStyleSheet = m_settings.value("/StyleSheet").toString();
 	m_settings.endGroup();
 
 	m_settings.endGroup(); // Preferences
@@ -405,7 +406,7 @@ void qtractorOptions::saveOptions (void)
 {
 	// Make program version available in the future.
 	m_settings.beginGroup("/Program");
-	m_settings.setValue("/Version", CONFIG_BUILD_VERSION);
+	m_settings.setValue("/Version", PROJECT_VERSION);
 	m_settings.endGroup();
 
 	// And go into general options group.
@@ -701,6 +702,7 @@ void qtractorOptions::saveOptions (void)
 	m_settings.beginGroup("/Custom");
 	m_settings.setValue("/ColorTheme", sCustomColorTheme);
 	m_settings.setValue("/StyleTheme", sCustomStyleTheme);
+	m_settings.setValue("/StyleSheet", sCustomStyleSheet);
 	m_settings.endGroup();
 
 	m_settings.endGroup(); // Preferences
@@ -850,7 +852,7 @@ bool qtractorOptions::parse_args ( const QStringList& args )
 			out << '\n';
 			out << QString("%1: %2\n")
 				.arg(QTRACTOR_TITLE)
-				.arg(CONFIG_BUILD_VERSION);
+				.arg(PROJECT_VERSION);
 			return false;
 		} else {
 			// If we don't have one by now,
@@ -1013,6 +1015,80 @@ void qtractorOptions::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 }
 
 
+void qtractorOptions::loadComboBoxFileHistory ( QComboBox *pComboBox )
+{
+	// Load combobox list from configuration settings file...
+	const bool bBlockSignals = pComboBox->blockSignals(true);
+	m_settings.beginGroup("/History");
+	const QStringList& files
+		= m_settings.value('/' + pComboBox->objectName()).toStringList();
+	QStringListIterator iter(files);
+	while (iter.hasNext()) {
+		const QFileInfo info(iter.next());
+		if (info.exists() && info.isReadable()) {
+			const QString& sPath = info.canonicalFilePath();
+			pComboBox->insertItem(0, info.fileName(), sPath);
+		}
+	}
+	m_settings.endGroup();
+	pComboBox->blockSignals(bBlockSignals);
+}
+
+
+void qtractorOptions::saveComboBoxFileHistory ( QComboBox *pComboBox )
+{
+	// Save combobox list to configuration settings file...
+	m_settings.beginGroup("/History");
+	QStringList files;
+	const int iCount = pComboBox->count();
+	for (int i = 0; i < iCount; ++i) {
+		const QString& sPath = pComboBox->itemData(i).toString();
+		if (!sPath.isEmpty())
+			files.prepend(sPath);
+	}
+	m_settings.setValue('/' + pComboBox->objectName(), files);
+	m_settings.endGroup();
+}
+
+
+// Combo box settter/gettter helper prototypes.
+bool qtractorOptions::setComboBoxCurrentFile (
+	QComboBox *pComboBox, const QString& sFilename )
+{
+	const bool bBlockSignals = pComboBox->blockSignals(true);
+	const QFileInfo info(sFilename);
+	const bool bResult = info.exists() && info.isReadable();
+	if (bResult) {
+		const QString& sPath = info.canonicalFilePath();
+		int iIndex = pComboBox->findData(sPath);
+		if (iIndex < 0) {
+			pComboBox->insertItem(0, info.fileName(), sPath);
+			iIndex = 0;
+		}
+		pComboBox->setCurrentIndex(iIndex);
+		pComboBox->setToolTip(sPath);
+	} else {
+		pComboBox->setCurrentIndex(pComboBox->count() - 1);
+		pComboBox->setToolTip(pComboBox->currentText());
+	}
+	pComboBox->blockSignals(bBlockSignals);
+
+	return bResult;
+}
+
+
+QString qtractorOptions::comboBoxCurrentFile ( QComboBox *pComboBox )
+{
+	QString sPath;
+
+	const int iIndex = pComboBox->currentIndex();
+	if (iIndex >= 0)
+		sPath = pComboBox->itemData(iIndex).toString();
+
+	return sPath;
+}
+
+
 //---------------------------------------------------------------------------
 // Splitter widget sizes persistence helper methods.
 
