@@ -1,7 +1,7 @@
 // qtractorPluginCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -589,7 +589,7 @@ qtractorPluginParamCommand::qtractorPluginParamCommand (
 	qtractorPlugin::Param *pParam, float fValue, bool bUpdate )
 	: qtractorCommand(pParam->name()),
 		m_pParam(pParam), m_fValue(fValue), m_bUpdate(bUpdate),
-		m_fPrevValue(pParam->value())
+		m_fPrevValue(pParam->prevValue())
 {
 	setRefresh(false);
 
