@@ -1,7 +1,7 @@
 // qtractorPluginFactory.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1063,7 +1063,7 @@ bool qtractorPluginFactory::Scanner::start (void)
 		sLibPath.remove(CONFIG_BINDIR);
 		sLibPath.append(CONFIG_LIBDIR);
 		sLibPath.append(QDir::separator());
-		sLibPath.append(PACKAGE_TARNAME);
+		sLibPath.append(PROJECT_NAME);
 		fi = QFileInfo(sLibPath, sName);
 	}
 
