@@ -49,6 +49,7 @@
 
 #include <QWidget>
 #include <QVBoxLayout>
+#include <QIcon>
 
 #include <QTimer>
 #include <QTimerEvent>
@@ -3321,6 +3322,7 @@ void qtractorVst3Plugin::openEditor ( QWidget *pParent )
 	m_pEditorWidget = new EditorWidget(pParent, wflags);
 	m_pEditorWidget->setAttribute(Qt::WA_QuitOnClose, false);
 	m_pEditorWidget->setWindowTitle(pType->name());
+	m_pEditorWidget->setWindowIcon(QIcon(":/images/qtractorPlugin.svg"));
 	m_pEditorWidget->setPlugin(this);
 
 	m_pEditorFrame = new EditorFrame(plugView, m_pEditorWidget);
